pub struct CalcUtResult {
pub longitude: f64,
pub latitude: f64,
pub distance_au: f64,
pub speed_longitude: f64,
pub speed_latitude: f64,
pub speed_distance_au: f64,
pub status: i32,
pub serr: String,
}
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.