pub struct PhenoUtResult {
pub phase_angle: f64,
pub phase_illuminated: f64,
pub elongation_of_planet: f64,
pub apparent_dimaeter_of_disc: f64,
pub apparent_magnitude: f64,
pub status: i32,
pub serr: String,
}
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.